@@ -196,6 +196,7 @@ class ContinuousGenerator(keras.utils.Sequence):
         batch_size=32,
         shuffle_batch=True,
         feature_kwargs={},
+        update_kwargs={},
         verbose=1,
         ndim=3,
     ):
@@ -216,6 +217,10 @@ class ContinuousGenerator(keras.utils.Sequence):
         self.batch_size = batch_size
         self.shuffle_batch = shuffle_batch
         self.feature_kwargs = feature_kwargs
+        self.update_kwargs = update_kwargs
+        if not isinstance(self.update_kwargs, list):
+            self.update_kwargs = itertools.cycle([update_kwargs])
+
         self.ndim = ndim
 
         self.lock = threading.Lock()
@@ -332,9 +337,10 @@ class ContinuousGenerator(keras.utils.Sequence):
 
     def _get(self, features: Feature or List[Feature], feature_kwargs) -> Image:
         # Updates and resolves a feature or list of features.
-        if isinstance(features, List):
-            for feature in features:
-                feature.update()
+        if isinstance(features, list):
+
+            for feature, update_kw in zip(features, self.update_kwargs):
+                feature.update(**update_kw)
 
             if not isinstance(feature_kwargs, list):
                 feature_kwargs = itertools.cycle([feature_kwargs])
